--[[
@title:       fillTypeOverlays
@description: Adds new overlays for fillTypes.
@author:      Jakob Tischler
@date:        27 Jan 2014
@version:     0.4

@contact:     jakobgithub -tt- gmail -dot- com
]]

fillTypeOverlays = {}
fillTypeOverlays.modDir = g_currentModDirectory;
addModEventListener(fillTypeOverlays);

function fillTypeOverlays:loadMap(name)
	print("## fillTypeOverlays v0.4 by Jakob Tischler loaded");

	self.debugActive = false;

	self.sets = {
		[1] = { name = 'giants', active = true },
		[2] = { name = 'coloredMinimalistic', active = false }
	};
	self.overlayDir = fillTypeOverlays.modDir .. 'giants/';
	self:dbg(string.format('self.overlayDir=%q', self.overlayDir));

	local configFile = getUserProfileAppPath() .. 'fillTypeOverlays.xml';
	if fileExists(configFile) then -- load config file
		configFile = loadXMLFile('fillTypeOverlays', configFile, 'fillTypeOverlays');
		local i = 1;
		while true do
			local key = ('fillTypeOverlays.set%d'):format(i);
			if not hasXMLProperty(configFile, key) then break; end;
			self:dbg(string.format('check fillTypeOverlays.set%d', i));

			local active = getXMLBool(configFile, key .. '#active');
			local name = getXMLString(configFile, key .. '#name');

			self:dbg(string.format('\t#name=%q, #active=%q', tostring(name), tostring(active)));
			if name ~= nil and active then
				self.overlayDir = fillTypeOverlays.modDir .. name .. '/';
				self:dbg(string.format('\tself.overlayDir=%q', tostring(self.overlayDir)));
				break;
			end;
			i = i + 1;
		end;
		delete(configFile);

	else -- create config file - should only happen once
		configFile = createXMLFile('fillTypeOverlays', configFile, 'fillTypeOverlays');
		for i=1,#self.sets do
			local name, active = self.sets[i].name, self.sets[i].active;

			local key = ('fillTypeOverlays.set%d'):format(i);
			self:dbg(string.format('createXMLFile(): key=%q', tostring(key)));
			setXMLString(configFile, key .. '#name', name);
			setXMLBool(configFile, key .. '#active', name == 'giants');
			self:dbg(string.format('setXMLString(..., %q, %s', key .. '#name', name));
			self:dbg(string.format('setXMLBool(..., %q, %s', key .. '#active', tostring(name == 'giants')));
		end;
		saveXMLFile(configFile);
		delete(configFile);
	end;


	local renderFillTypeOverlay = function(self)
		if self.isClient and self.currentFillType and self.currentFillType ~= Fillable.FILLTYPE_UNKNOWN and self.fillLevel and self.fillLevel > 0 and g_currentMission.fillTypeOverlays[self.currentFillType] then
			g_currentMission:setFillTypeOverlayFillType(self.currentFillType);
		end;
	end;
	Sprayer.draw = Utils.prependedFunction(Sprayer.draw, renderFillTypeOverlay);
	FuelTrailer.draw = Utils.prependedFunction(FuelTrailer.draw, renderFillTypeOverlay);
	-- 'SowingMachine' not needed/possible: has its own seed type overlay

	for i=1,Fillable.NUM_FILLTYPES do
		local desc = Fillable.fillTypeIndexToDesc[i];
		local name = desc.name;
		local filePath = Utils.getFilename(name .. '.dds', self.overlayDir);
		if fileExists(filePath) then
			self:dbg(string.format('\tfillType %d (%q / %q): filename="%s.dds"', i, tostring(name), tostring(desc.nameI18N), tostring(name)));
			if g_currentMission.fillTypeOverlays[i] then
				self:dbg(string.format('\t\tdelete existing overlay (id %s)', tostring(g_currentMission.fillTypeOverlays[i].overlayId)));
				g_currentMission.fillTypeOverlays[i]:delete();
				g_currentMission.fillTypeOverlays[i] = nil;
			end;
			g_currentMission:addFillTypeOverlay(i, filePath);
			print(string.format('\t\tfillType overlay "%s.dds" loaded for fillType %q (%q)', tostring(name), tostring(name), tostring(desc.nameI18N)));
		end;
	end;

	if self.debugActive then
		for i,overlayData in pairs(g_currentMission.fillTypeOverlays) do
			self:dbg(string.format('fillType %d (%q / %q) has overlay', i, tostring(Fillable.fillTypeIntToName[i]), tostring(Fillable.fillTypeIndexToDesc[i].nameI18N)));
		end;
	end;

	if (self.initialized) then
		return;
	end;

	self.initialized = true;
end;

function fillTypeOverlays:deleteMap()
	self.initialized = false;
end;

function fillTypeOverlays:keyEvent(unicode, sym, modifier, isDown)
end;

function fillTypeOverlays:update(dt)
end;

function fillTypeOverlays:updateTick(dt)
end;

function fillTypeOverlays:draw()
end;

function fillTypeOverlays:mouseEvent(posX, posY, isDown, isUp, button)
end;

function fillTypeOverlays:dbg(str)
	if self.debugActive then
		print(tostring(str));
	end;
end;
